.. cosmic documentation master file, created by
   sphinx-quickstart on Thu Nov 15 20:31:55 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Cosmic in Python
================

Here you will find the documentation for the Python implementation of Cosmic.
The tutorial should be the best way to get up and running.

Contents:

.. toctree::
   :maxdepth: 3

   overview
   tutorial
   guide
   reference
   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

